==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebCardActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardActionsDescription } from "./WebCardActionsDescription";
/**
 * @hidden
 */
export let WebCardActionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCardActionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCardActionsDescriptionMetadata.a == null) {
                WebCardActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCardActionsDescriptionMetadata.c(WebCardActionsDescriptionMetadata.a);
            }
            if (a.j(WebCardActionsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebCardActionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CardActions");
            a.item("__tagNameWC", "String:igc-card-actions");
            a.item("Orientation", "ExportedType:string:CardActionsOrientation");
            a.item("Orientation@names", "Vertical;Horizontal");
        }
        static d(a) {
            WebCardActionsDescriptionMetadata.b(a);
            a.aa("WebCardActions", () => new WebCardActionsDescription());
            a.z("WebCardActions", WebCardActionsDescriptionMetadata.a);
        }
    }
    WebCardActionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCardActionsDescriptionMetadata, 'WebCardActionsDescriptionMetadata');
    WebCardActionsDescriptionMetadata.a = null;
    return WebCardActionsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebCardActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardActionsDescription } from "./WebCardActionsDescription";
/**
 * @hidden
 */
export let WebCardActionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCardActionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebCardActionsDescriptionMetadata.a == null) {
                WebCardActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCardActionsDescriptionMetadata.c(WebCardActionsDescriptionMetadata.a);
            }
            if (a.k(WebCardActionsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCardActionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CardActions");
            a.item("__tagNameWC", "String:igc-card-actions");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Orientation", "ExportedType:string:CardActionsOrientation");
            a.item("Orientation@names", "Vertical;Horizontal");
        }
        static d(a) {
            WebCardActionsDescriptionMetadata.b(a);
            a.ac("WebCardActions", () => new WebCardActionsDescription());
            a.ab("WebCardActions", WebCardActionsDescriptionMetadata.a);
        }
    }
    WebCardActionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCardActionsDescriptionMetadata, 'WebCardActionsDescriptionMetadata');
    WebCardActionsDescriptionMetadata.a = null;
    return WebCardActionsDescriptionMetadata;
})();
